@@ -1,3 +1,5 @@
+#define NPY_HAVE_ENDIAN_H 1
+#define NPY_HAVE_SYS_ENDIAN_H 1
 #define NPY_SIZEOF_SHORT SIZEOF_SHORT
 #define NPY_SIZEOF_INT SIZEOF_INT
 #define NPY_SIZEOF_LONG SIZEOF_LONG
@@ -5,9 +7,10 @@
 #define NPY_SIZEOF_COMPLEX_FLOAT 8
 #define NPY_SIZEOF_DOUBLE 8
 #define NPY_SIZEOF_COMPLEX_DOUBLE 16
-#define NPY_SIZEOF_LONGDOUBLE 12
-#define NPY_SIZEOF_COMPLEX_LONGDOUBLE 24
+#define NPY_SIZEOF_LONGDOUBLE 8
+#define NPY_SIZEOF_COMPLEX_LONGDOUBLE 16
 #define NPY_SIZEOF_PY_INTPTR_T 4
+#define NPY_SIZEOF_OFF_T 8
 #define NPY_SIZEOF_PY_LONG_LONG 8
 #define NPY_SIZEOF_LONGLONG 8
 #define NPY_NO_SMP 0
@@ -15,14 +18,15 @@
 #define NPY_HAVE_DECL_ISINF
 #define NPY_HAVE_DECL_ISFINITE
 #define NPY_HAVE_DECL_SIGNBIT
-#define NPY_USE_C99_COMPLEX
+#define NPY_USE_C99_COMPLEX 1
 #define NPY_HAVE_COMPLEX_DOUBLE 1
 #define NPY_HAVE_COMPLEX_FLOAT 1
 #define NPY_HAVE_COMPLEX_LONG_DOUBLE 1
+#define NPY_RELAXED_STRIDES_CHECKING 1
 #define NPY_USE_C99_FORMATS 1
 #define NPY_VISIBILITY_HIDDEN __attribute__((visibility("hidden")))
 #define NPY_ABI_VERSION 0x01000009
-#define NPY_API_VERSION 0x00000006
+#define NPY_API_VERSION 0x0000000C
 
 #ifndef __STDC_FORMAT_MACROS
 #define __STDC_FORMAT_MACROS 1
